@@ -1,4 +1,4 @@
-/* $Id: gdict-speller.c,v 1.17 2002/04/26 11:50:22 gman Exp $ */
+/* $Id: gdict-speller.c,v 1.23 2003/05/31 05:54:47 dcransto Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -41,6 +41,8 @@ enum {
     LAST_SIGNAL
 };
 
+#define GDICT_SPELL 100
+
 GtkWidget *ss_label;
 
 static gint gdict_speller_signals[LAST_SIGNAL] = { 0, 0, 0 };
@@ -111,8 +113,8 @@ gdict_speller_get_type (void) {
 static void 
 gdict_speller_init (GDictSpeller *speller) {
     GtkWidget *label, *button, *scrolled_win;
-    GtkWidget *sep;
     GtkWidget *hbox;
+    GtkWidget *vbox;
     GtkListStore *model;
     GtkTreeViewColumn *column;
     GtkTreeSelection *selection;
@@ -123,68 +125,62 @@ gdict_speller_init (GDictSpeller *speller) {
     speller->spell_cmd = NULL;
     speller->strat = gdict_pref.dfl_strat;
     
-    hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
+    vbox = gtk_vbox_new (FALSE, 6);
+    g_object_set (G_OBJECT (vbox), "border_width", 5, NULL);
     
-    label = gtk_label_new_with_mnemonic (_("_Word : "));
+    hbox = gtk_hbox_new (FALSE, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    label = gtk_label_new_with_mnemonic (_("_Word:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     
     speller->word_entry = GTK_ENTRY (gtk_entry_new ());
-    gtk_label_set_mnemonic_widget ( GTK_LABEL(label), GTK_WIDGET(speller->word_entry));
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (speller->word_entry));
 
     gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (speller->word_entry), TRUE, TRUE, 0);
     g_signal_connect (G_OBJECT (speller->word_entry), "activate",
     	  	      G_CALLBACK (spell_entry_cb), speller);
 
-    if ( gail_loaded )
-
+    if (gail_loaded)
     {
-        add_atk_namedesc(label, _("Word"), _("Word"));
-        add_atk_namedesc(GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
-        add_atk_relation(GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
-
+        add_atk_namedesc (label, _("Word"), _("Word"));
+        add_atk_namedesc (GTK_WIDGET(speller->word_entry), _("Word Entry"), _("Enter a word to know the spelling"));
+        add_atk_relation (GTK_WIDGET(speller->word_entry), label, ATK_RELATION_LABELLED_BY);
     }
- 
-    label = gtk_label_new_with_mnemonic (_("_Spell"));
-    gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 1);
+      
+    speller->hbox = gtk_hbox_new (FALSE, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), speller->hbox, FALSE, FALSE, 0);
     
-    button = gtk_button_new ();
-    gtk_container_add (GTK_CONTAINER (button), label);
+    ss_label = gtk_label_new_with_mnemonic (_("Search s_trategy:"));
+    gtk_box_pack_start (GTK_BOX (speller->hbox), ss_label, FALSE, FALSE, 0);
+        
+    
+    hbox = gtk_hbutton_box_new ();
+    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
+		    
+    button = gdict_button_new_with_stock_image (_("Check _Spelling"), GTK_STOCK_SPELL_CHECK);
     gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (spell_button_pressed),
     		      speller);
-    if( gail_loaded )
-        add_atk_namedesc(GTK_WIDGET(button), NULL, _("Click to do the spell check"));
-    speller->hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-    gtk_container_set_border_width (GTK_CONTAINER (speller->hbox), GNOME_PAD);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), speller->hbox, 
-    			FALSE, FALSE, 0);
+    if (gail_loaded)
+        add_atk_namedesc (GTK_WIDGET (button), NULL, _("Click to do the spell check"));
+
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    ss_label = gtk_label_new_with_mnemonic (_("Search S_trategy:"));
-    gtk_label_set_justify (GTK_LABEL (ss_label), GTK_JUSTIFY_RIGHT);
-    gtk_misc_set_alignment (GTK_MISC (ss_label), 1, 0.5);
-    gtk_box_pack_start (GTK_BOX (speller->hbox), ss_label, FALSE, FALSE, 0);
-        
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, 
-    			FALSE, GNOME_PAD_SMALL);
-    
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), hbox, FALSE, FALSE, 0);
-    
-    label = gtk_label_new (_("Search Results"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    
-    sep = gtk_hseparator_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), sep, TRUE, TRUE, GNOME_PAD_SMALL);
+    label = gtk_label_new_with_mnemonic (_("Search _results:"));
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+    g_object_set (G_OBJECT (label), "xalign", 0.0, NULL);
+    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
     
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (scrolled_win));
+
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
                                     GTK_POLICY_NEVER,
                                     GTK_POLICY_AUTOMATIC);
-    gtk_widget_set_usize (scrolled_win, 400, 250);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (speller)->vbox), scrolled_win, 
-    			TRUE, TRUE, GNOME_PAD);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_win),
+					 GTK_SHADOW_NONE);
+    gtk_widget_set_size_request (scrolled_win, 400, 250);
     
     model = gtk_list_store_new (1, G_TYPE_STRING);
     
@@ -192,6 +188,8 @@ gdict_speller_init (GDictSpeller *speller) {
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (speller->word_list), FALSE);
     g_object_unref (G_OBJECT (model));
     
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (speller->word_list));
+
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (speller->word_list));
     g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (row_selected_cb),
     		      speller);
@@ -207,20 +205,32 @@ gdict_speller_init (GDictSpeller *speller) {
                                           0,GTK_SORT_ASCENDING); */
                                           
     gtk_tree_view_append_column (GTK_TREE_VIEW (speller->word_list), column);
+
     gtk_container_add (GTK_CONTAINER (scrolled_win), speller->word_list);
-
-    gtk_dialog_add_buttons (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                                                  _("_Look Up Word"), 100,
-                                                  NULL);
-
-    gtk_dialog_set_default_response (GTK_DIALOG (speller), 100);
+    gtk_box_pack_start (GTK_BOX (vbox), scrolled_win, TRUE, TRUE, 0);
+   
+    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (speller)->vbox), vbox);
+		    
+    gtk_dialog_add_button (GTK_DIALOG (speller), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+    gdict_dialog_add_button (GTK_DIALOG (speller), _("_Look Up Word"), GTK_STOCK_FIND, GDICT_SPELL);
+	   
+    gtk_dialog_set_default_response (GTK_DIALOG (speller), GDICT_SPELL);
     g_signal_connect (G_OBJECT (speller->word_list), "row_activated",
     		      G_CALLBACK (row_activated_cb), speller);
     		      
-    g_signal_connect (G_OBJECT (speller), "response", G_CALLBACK (spell_response_cb),
+    g_signal_connect (G_OBJECT (speller), "response", 
+		      G_CALLBACK (spell_response_cb),
     		      speller);
-    gtk_window_set_title (GTK_WINDOW (speller), _("Spell checker"));
-                           
+
+    /* To prevent dialog destruction when pressing ESC */
+    g_signal_connect (G_OBJECT (speller), "delete_event", 
+		      G_CALLBACK (gtk_true), NULL);
+
+
+    gtk_window_set_title (GTK_WINDOW (speller), _("Check Spelling"));
+    gtk_dialog_set_has_separator (GTK_DIALOG (speller), FALSE);
+    g_object_set (G_OBJECT (speller), "border_width", 5, NULL);
+                          
     gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (speller)->vbox));
 }
 
@@ -474,7 +484,7 @@ spell_error_cb (dict_command_t *command, DictStatusCode code,
         string = g_strdup_printf (_("Error invoking query: %s"), message);
         dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  	 "%s", string, NULL); 
+                                  	 "%s", string); 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
         g_free (string);
@@ -541,6 +551,7 @@ speller_add_strat (GDictSpeller *speller, gchar *strat, gchar *desc) {
     
     label = gtk_label_new (desc);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
     
     menu_item = gtk_menu_item_new ();
     gtk_signal_connect (GTK_OBJECT (menu_item), "activate", 
@@ -655,7 +666,7 @@ spell_response_cb (GtkDialog *dialog, gint id, gpointer data) {
 	case GTK_RESPONSE_CLOSE:
 		gtk_widget_hide (GTK_WIDGET (dialog));
 		break;
-	case 100:
+	case GDICT_SPELL:
 		speller_lookup (speller);
 		break;
 	default:
